@@ -46,6 +46,7 @@ class API:
     hist = Importable('easier.hvtools', 'hist')
     Animator = Importable('easier.hvtools', 'Animator')
     beta_plots = Importable('easier.hvtools', 'beta_plots')
+    in_notebook = Importable('easier.utils', 'in_notebook')
     Item = Importable('easier.item', 'Item')
     iterify = Importable('easier.iterify', 'iterify')
     mem_show = Importable('easier.memory', 'mem_show')
@@ -54,6 +55,7 @@ class API:
     ParamState = Importable('easier.param_state', 'ParamState')
     figure = Importable('easier.plotting', 'figure')
     PG = Importable('easier.postgres', 'PG')
+    pg_creds_from_env = Importable('easier.postgres', 'pg_creds_from_env')
     PrintCatcher = Importable('easier.print_catcher', 'PrintCatcher')
     SalesForceReport = Importable('easier.salesforce', 'SalesForceReport')
     Soql = Importable('easier.salesforce', 'Soql')
@@ -79,6 +81,7 @@ class API:
     pickle_cache_state = Importable('easier.utils', 'pickle_cache_state')
     pickle_cached_container = Importable('easier.utils', 'pickle_cached_container')
     print_error = Importable('easier.utils', 'print_error')
+    python_type = Importable('easier.utils', 'python_type')
     django_reconnect = Importable('easier.utils', 'django_reconnect')
     screen_width_full = Importable('easier.utils', 'screen_width_full')
     BlobMixin = Importable('easier.utils', 'BlobMixin')
@@ -87,3 +90,4 @@ class API:
     get_logger = Importable('easier.utils', 'get_logger')
     cc = Importable('easier.plotting', 'ColorCyle', instantiate=True)
     Proportion = Importable('easier.proportion_lib', 'Proportion')
+    tqdm_flex = Importable('easier.utils', 'tqdm_flex')
