@@ -39,7 +39,3 @@ class ColorCyle:
 
     def __getitem__(self, index):
         return self._code_repeats[index]
-
-
-def get_cc():
-    return ColorCyle()
