@@ -9,6 +9,48 @@ from copy import copy, deepcopy
 from textwrap import dedent
 
 
+def tqdm_flex(iterable):
+    """
+    Adds the appropriate tqdm wrapper around an iterable
+    """
+    import easier as ezr
+    if ezr.in_notebook():
+        try:
+            import tqdm.notebook as tqdm
+            return tqdm.tqdm(iterable)
+        except:
+            return iterable
+    else:
+        try:
+            import tqdm
+            return tqdm.tqdm(iterable)
+        except:
+            return iterable
+
+
+def python_type():
+    """
+    A utility to determine if running under ipython or jupyter
+    """
+    try:
+        shell = get_ipython().__class__.__name__
+        if shell == 'ZMQInteractiveShell':
+            return 'jupyter'   # Jupyter notebook or qtconsole
+        elif shell == 'TerminalInteractiveShell':
+            return 'ipython'  # Terminal running IPython
+        else:
+            return 'other'  # Other type (?)
+    except NameError:
+        return 'other'      # Probably standard Python interpreter
+
+
+def in_notebook():
+    """
+    Determine if running in notebook (see python_type)
+    """
+    return python_type() == 'jupyter'
+
+
 def django_reconnect():  # pragma: no cover
     """
     Fixes dropped postgres connection in jupyter notebooks.
